package com.digia.trial;

import servicestub.ISequence;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.app.AlertDialog.Builder;
import android.content.ComponentName;
import android.content.ContentResolver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.ServiceConnection;
import android.database.Cursor;
import android.graphics.Color;
import android.os.Bundle;
import android.os.IBinder;
import android.os.RemoteException;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

public class Main extends Activity {
	protected static final int MY_DEMO_NOTE = 0;

	private static final int MY_DIALOG = 0;
	
	private static final int MY_BROADCAST_CMD = 100;
	private static final int MY_EXIT_CMD = 101;

	private Cursor cursor = null;
	
	private int counter = 0;
	
	private ISequence serviceImpl = null;
	
	private final ServiceConnection connection = new ServiceConnection() {
		
		@Override
		public void onServiceDisconnected(ComponentName name) {
			serviceImpl = null;
		}
		
		@Override
		public void onServiceConnected(ComponentName name, IBinder service) {
			serviceImpl = ISequence.Stub.asInterface(service);
		}
	};
	
	private final OnClickListener buttonListener = new OnClickListener() {
		@Override
		public void onClick(View v) {
			if (0 == counter%2) {
				v.setBackgroundColor(Color.RED);
			} else {
				v.setBackgroundColor(Color.GREEN);
			}
			
			++counter;
			
			//Toast.makeText(Main.this, "click", Toast.LENGTH_SHORT).show();
			
			if (0 == (counter%10)) {
				showDialog(MY_DIALOG);
			}
			
			if(null==serviceImpl){
				final boolean result = bindService(
						new Intent(ISequence.class.getName()), 
						connection, 
						Service.BIND_AUTO_CREATE);
				
				if (!result){
					Toast.makeText(
						Main.this, 
						getString(R.string.ErrorUnableToBind), 
						Toast.LENGTH_SHORT).show();
				}
			} else {
				try {
					int value = serviceImpl.getSequence();
					Button button = (Button)v;
					button.setText(new Integer(value).toString());
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}
	};
	
	private final OnClickListener showListener = new OnClickListener() {
		
		@Override
		public void onClick(View v) {
			Notification notification = new Notification(
					android.R.id.icon, 
					getString(R.string.NotificationNewNotification), 
					System.currentTimeMillis());
			notification.flags |= Notification.FLAG_AUTO_CANCEL;
			Context applicatioContext = getApplicationContext();
			Intent intent = new Intent(Main.this, Main.class);
			PendingIntent pendingIntent = PendingIntent.getActivity(
					applicatioContext, 
					MY_DEMO_NOTE, 
					intent, 
					0);
			notification.setLatestEventInfo(
					applicatioContext, 
					getString(R.string.NotificationTitle), 
					getString(R.string.NotificationContent), 
					pendingIntent);
			NotificationManager 
				manager = (NotificationManager)getSystemService(
						NOTIFICATION_SERVICE);
			manager.notify(MY_DEMO_NOTE, notification);
		}
	};
	
	private final OnClickListener hideListener = new OnClickListener() {
		@Override
		public void onClick(View v) {
			NotificationManager 
				manager = (NotificationManager)getSystemService(
						NOTIFICATION_SERVICE);
			manager.cancel(MY_DEMO_NOTE);
		}
	};
	
	private final OnClickListener nextListener = new OnClickListener() {
		
		@Override
		public void onClick(View v) {
			if(null == cursor){
				ContentResolver resolver = getContentResolver();
				cursor = resolver.query(
					NumberProvider.CONTENT_URI, null, null, null, null);
				startManagingCursor(cursor);
				cursor.moveToFirst();
			}
			
			final int value = cursor.getInt(0);
			cursor.moveToNext();
			
			if(cursor.isAfterLast()){
				cursor.moveToFirst();
			}
			
			Button thisButton = (Button)v;
			thisButton.setText(new Integer(value).toString());
		}
	};
	
	protected android.app.Dialog onCreateDialog(int id) {
		Dialog result = null;
		
		if (MY_DIALOG == id){
			AlertDialog.Builder builder = new Builder(this);
			DialogInterface.OnClickListener 
				yesListener = new DialogInterface.OnClickListener() {
				
				@Override
				public void onClick(DialogInterface dialog, int which) {
					Main.this.finish();
				}
			};
			DialogInterface.OnClickListener 
				noListener = new DialogInterface.OnClickListener() {
				
				@Override
				public void onClick(DialogInterface dialog, int which) {
					dialog.cancel();
				}
			};
			
			builder.setMessage(getString(R.string.DialogMessage));
			builder.setPositiveButton(getString(R.string.DialogYes), yesListener);
			builder.setNegativeButton(getString(R.string.DialogNo), noListener);
			
			result = builder.create();
		}
		
		return result;
	};
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		menu.add(0, MY_BROADCAST_CMD, 0, R.string.MenuItemBroadcast); 
		menu.add(R.string.MenuItemAnother);
		menu.add(0, MY_EXIT_CMD, 2, R.string.MenuItemExit);
		return true;
	};
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		final int id = item.getItemId();
		
		if (MY_EXIT_CMD == id){
			showDialog(MY_DIALOG);
			return true;
		} else if (MY_BROADCAST_CMD == id){
			sendBroadcast(new Intent("yahoo"));
		}
		
		return false;
	};
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        Button button = (Button)findViewById(R.id.FirstButton);
        button.setOnClickListener(buttonListener);
        
        Button showButton = (Button)findViewById(R.id.StartButton);
        showButton.setOnClickListener(showListener);
        
        Button hideButton = (Button)findViewById(R.id.StopButton);
        hideButton.setOnClickListener(hideListener);
        
        Button nextButton = (Button)findViewById(R.id.NextButton);
        nextButton.setOnClickListener(nextListener);
    }
}
